# TreadI repository_lists.d/

TreadI's repo-picker screen displays all repository lists present in the `repository_lists.d` directory.

To create one, follow the instructions at:

https://sloretz.github.io/TreadI/reference/custom-repository-list.html
